@@ -10,7 +10,7 @@ package Devel::Cover;
 use strict;
 use warnings;
 
-our $VERSION = '1.06'; # VERSION
+our $VERSION = '1.07'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 use DynaLoader ();
@@ -653,10 +653,11 @@ sub sub_info
 {
     my ($cv) = @_;
     my ($name, $start) = ("--unknown--", 0);
-    if (!$cv->GV->isa("B::SPECIAL"))
+    my $gv = $cv->GV;
+    if ($gv && !$gv->isa("B::SPECIAL"))
     {
-        return unless $cv->GV->can("SAFENAME");
-        $name = $cv->GV->SAFENAME;
+        return unless $gv->can("SAFENAME");
+        $name = $gv->SAFENAME;
         # print STDERR "--[$name]--\n";
         $name =~ s/(__ANON__)\[.+:\d+\]/$1/ if defined $name;
     }
@@ -755,6 +756,7 @@ EOM
 sub _report
 {
     local @SIG{qw(__DIE__ __WARN__)};
+    # $SIG{__DIE__} = \&Carp::confess;
 
     $Run{finish} = get_elapsed() / 1e6;
 
@@ -1269,9 +1271,10 @@ sub get_cover
 
     if ($Pod && $Coverage{pod})
     {
-        unless ($cv->GV->isa("B::SPECIAL"))
+        my $gv = $cv->GV;
+        if ($gv && !$gv->isa("B::SPECIAL"))
         {
-            my $stash = $cv->GV->STASH;
+            my $stash = $gv->STASH;
             my $pkg   = $stash->NAME;
             my $file  = $cv->FILE;
             my %opts;
@@ -1360,7 +1363,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
